@@ -27,7 +27,7 @@ func TestCommitResetToCommit(t *testing.T) {
 	runner.CheckForMissingCalls()
 }
 
-func TestCommitCommitObj(t *testing.T) {
+func TestCommitCommitCmdObj(t *testing.T) {
 	type scenario struct {
 		testName             string
 		message              string
@@ -89,6 +89,62 @@ func TestCommitCommitObj(t *testing.T) {
 	}
 }
 
+func TestCommitCommitEditorCmdObj(t *testing.T) {
+	type scenario struct {
+		testName      string
+		configSignoff bool
+		configVerbose string
+		expected      string
+	}
+
+	scenarios := []scenario{
+		{
+			testName:      "Commit using editor",
+			configSignoff: false,
+			configVerbose: "default",
+			expected:      `git commit`,
+		},
+		{
+			testName:      "Commit with --no-verbose flag",
+			configSignoff: false,
+			configVerbose: "never",
+			expected:      `git commit --no-verbose`,
+		},
+		{
+			testName:      "Commit with --verbose flag",
+			configSignoff: false,
+			configVerbose: "always",
+			expected:      `git commit --verbose`,
+		},
+		{
+			testName:      "Commit with --signoff",
+			configSignoff: true,
+			configVerbose: "default",
+			expected:      `git commit --signoff`,
+		},
+		{
+			testName:      "Commit with --signoff and --no-verbose",
+			configSignoff: true,
+			configVerbose: "never",
+			expected:      `git commit --signoff --no-verbose`,
+		},
+	}
+
+	for _, s := range scenarios {
+		s := s
+		t.Run(s.testName, func(t *testing.T) {
+			userConfig := config.GetDefaultConfig()
+			userConfig.Git.Commit.SignOff = s.configSignoff
+			userConfig.Git.Commit.Verbose = s.configVerbose
+
+			instance := buildCommitCommands(commonDeps{userConfig: userConfig})
+
+			cmdStr := instance.CommitEditorCmdObj().ToString()
+			assert.Equal(t, s.expected, cmdStr)
+		})
+	}
+}
+
 func TestCommitCreateFixupCommit(t *testing.T) {
 	type scenario struct {
 		testName string
@@ -161,3 +217,49 @@ func TestCommitShowCmdObj(t *testing.T) {
 		})
 	}
 }
+
+func TestGetCommitMsg(t *testing.T) {
+	type scenario struct {
+		testName       string
+		input          string
+		expectedOutput string
+	}
+	scenarios := []scenario{
+		{
+			"empty",
+			` commit deadbeef`,
+			``,
+		},
+		{
+			"no line breaks (single line)",
+			`commit deadbeef
+use generics to DRY up context code`,
+			`use generics to DRY up context code`,
+		},
+		{
+			"with line breaks",
+			`commit deadbeef
+Merge pull request #1750 from mark2185/fix-issue-template
+
+'git-rev parse' should be 'git rev-parse'`,
+			`Merge pull request #1750 from mark2185/fix-issue-template
+
+'git-rev parse' should be 'git rev-parse'`,
+		},
+	}
+
+	for _, s := range scenarios {
+		s := s
+		t.Run(s.testName, func(t *testing.T) {
+			instance := buildCommitCommands(commonDeps{
+				runner: oscommands.NewFakeRunner(t).Expect("git rev-list --format=%B --max-count=1 deadbeef", s.input, nil),
+			})
+
+			output, err := instance.GetCommitMessage("deadbeef")
+
+			assert.NoError(t, err)
+
+			assert.Equal(t, s.expectedOutput, output)
+		})
+	}
+}
