@@ -2,20 +2,20 @@ package git_commands
 
 import (
 	"fmt"
+	"strings"
 
-	"github.com/jesseduffield/lazygit/pkg/commands/loaders"
 	"github.com/jesseduffield/lazygit/pkg/commands/oscommands"
 )
 
 type StashCommands struct {
 	*GitCommon
-	fileLoader  *loaders.FileLoader
+	fileLoader  *FileLoader
 	workingTree *WorkingTreeCommands
 }
 
 func NewStashCommands(
 	gitCommon *GitCommon,
-	fileLoader *loaders.FileLoader,
+	fileLoader *FileLoader,
 	workingTree *WorkingTreeCommands,
 ) *StashCommands {
 	return &StashCommands{
@@ -46,6 +46,19 @@ func (self *StashCommands) Save(message string) error {
 	return self.cmd.New("git stash save " + self.cmd.Quote(message)).Run()
 }
 
+func (self *StashCommands) Store(sha string, message string) error {
+	trimmedMessage := strings.Trim(message, " \t")
+	if len(trimmedMessage) > 0 {
+		return self.cmd.New(fmt.Sprintf("git stash store %s -m %s", self.cmd.Quote(sha), self.cmd.Quote(trimmedMessage))).Run()
+	}
+	return self.cmd.New(fmt.Sprintf("git stash store %s", self.cmd.Quote(sha))).Run()
+}
+
+func (self *StashCommands) Sha(index int) (string, error) {
+	sha, _, err := self.cmd.New(fmt.Sprintf("git rev-parse refs/stash@{%d}", index)).DontLog().RunWithOutputs()
+	return strings.Trim(sha, "\r\n"), err
+}
+
 func (self *StashCommands) ShowStashEntryCmdObj(index int) oscommands.ICmdObj {
 	cmdStr := fmt.Sprintf("git stash show -p --stat --color=%s --unified=%d stash@{%d}", self.UserConfig.Git.Paging.ColorArg, self.UserConfig.Git.DiffContextSize, index)
 
@@ -97,7 +110,7 @@ func (self *StashCommands) SaveStagedChanges(message string) error {
 	// meaning it's deleted in your working tree but added in your index. Given that it's
 	// now safely stashed, we need to remove it.
 	files := self.fileLoader.
-		GetStatusFiles(loaders.GetStatusFileOptions{})
+		GetStatusFiles(GetStatusFileOptions{})
 
 	for _, file := range files {
 		if file.ShortStatus == "AD" {
@@ -109,3 +122,25 @@ func (self *StashCommands) SaveStagedChanges(message string) error {
 
 	return nil
 }
+
+func (self *StashCommands) StashIncludeUntrackedChanges(message string) error {
+	return self.cmd.New(fmt.Sprintf("git stash save %s --include-untracked", self.cmd.Quote(message))).Run()
+}
+
+func (self *StashCommands) Rename(index int, message string) error {
+	sha, err := self.Sha(index)
+	if err != nil {
+		return err
+	}
+
+	if err := self.Drop(index); err != nil {
+		return err
+	}
+
+	err = self.Store(sha, message)
+	if err != nil {
+		return err
+	}
+
+	return nil
+}
