@@ -29,7 +29,11 @@ func (self *SyncCommands) PushCmdObj(opts PushOpts) (oscommands.ICmdObj, error)
 	cmdStr := "git push"
 
 	if opts.Force {
-		cmdStr += " --force-with-lease"
+		if self.version.IsOlderThan(2, 30, 0) {
+			cmdStr += " --force-with-lease"
+		} else {
+			cmdStr += " --force-with-lease --force-if-includes"
+		}
 	}
 
 	if opts.SetUpstream {
