@@ -1,6 +1,8 @@
 package git_commands
 
 import (
+	"fmt"
+
 	"github.com/jesseduffield/generics/slices"
 	"github.com/jesseduffield/lazygit/pkg/commands/models"
 	"github.com/jesseduffield/lazygit/pkg/commands/oscommands"
@@ -10,23 +12,31 @@ import (
 
 type TagLoader struct {
 	*common.Common
-	cmd oscommands.ICmdObjBuilder
+	version *GitVersion
+	cmd     oscommands.ICmdObjBuilder
 }
 
 func NewTagLoader(
 	common *common.Common,
+	version *GitVersion,
 	cmd oscommands.ICmdObjBuilder,
 ) *TagLoader {
 	return &TagLoader{
-		Common: common,
-		cmd:    cmd,
+		Common:  common,
+		version: version,
+		cmd:     cmd,
 	}
 }
 
 func (self *TagLoader) GetTags() ([]*models.Tag, error) {
 	// get remote branches, sorted  by creation date (descending)
 	// see: https://git-scm.com/docs/git-tag#Documentation/git-tag.txt---sortltkeygt
-	tagsOutput, err := self.cmd.New(`git tag --list --sort=-creatordate`).DontLog().RunWithOutput()
+	sortKey := "-creatordate"
+	if self.version.IsOlderThan(2, 7, 0) {
+		sortKey = "-v:refname"
+	}
+
+	tagsOutput, err := self.cmd.New(fmt.Sprintf(`git tag --list --sort=%s`, sortKey)).DontLog().RunWithOutput()
 	if err != nil {
 		return nil, err
 	}
