@@ -47,6 +47,15 @@ func TestGetPullRequestURL(t *testing.T) {
 				assert.Equal(t, "https://github.com/peter/calculator/compare/feature%2Fsum-operation?expand=1", url)
 			},
 		},
+		{
+			testName:  "Opens a link to new pull request on github with https remote url",
+			from:      "feature/sum-operation",
+			remoteUrl: "https://github.com/peter/calculator.git",
+			test: func(url string, err error) {
+				assert.NoError(t, err)
+				assert.Equal(t, "https://github.com/peter/calculator/compare/feature%2Fsum-operation?expand=1", url)
+			},
+		},
 		{
 			testName:  "Opens a link to new pull request on bitbucket with specific target branch",
 			from:      "feature/profile-page/avatar",
@@ -77,6 +86,16 @@ func TestGetPullRequestURL(t *testing.T) {
 				assert.Equal(t, "https://github.com/peter/calculator/compare/feature%2Foperations...feature%2Fsum-operation?expand=1", url)
 			},
 		},
+		{
+			testName:  "Opens a link to new pull request on github with https remote url with specific target branch",
+			from:      "feature/sum-operation",
+			to:        "feature/operations",
+			remoteUrl: "https://github.com/peter/calculator.git",
+			test: func(url string, err error) {
+				assert.NoError(t, err)
+				assert.Equal(t, "https://github.com/peter/calculator/compare/feature%2Foperations...feature%2Fsum-operation?expand=1", url)
+			},
+		},
 		{
 			testName:  "Opens a link to new pull request on gitlab",
 			from:      "feature/ui",
@@ -95,6 +114,15 @@ func TestGetPullRequestURL(t *testing.T) {
 				assert.Equal(t, "https://gitlab.com/peter/public/calculator/merge_requests/new?merge_request[source_branch]=feature%2Fui", url)
 			},
 		},
+		{
+			testName:  "Opens a link to new pull request on gitlab with https remote url in nested groups",
+			from:      "feature/ui",
+			remoteUrl: "https://gitlab.com/peter/public/calculator.git",
+			test: func(url string, err error) {
+				assert.NoError(t, err)
+				assert.Equal(t, "https://gitlab.com/peter/public/calculator/merge_requests/new?merge_request[source_branch]=feature%2Fui", url)
+			},
+		},
 		{
 			testName:  "Opens a link to new pull request on gitlab with specific target branch",
 			from:      "feature/commit-ui",
@@ -115,6 +143,25 @@ func TestGetPullRequestURL(t *testing.T) {
 				assert.Equal(t, "https://gitlab.com/peter/public/calculator/merge_requests/new?merge_request[source_branch]=feature%2Fcommit-ui&merge_request[target_branch]=epic%2Fui", url)
 			},
 		},
+		{
+			testName:  "Opens a link to new pull request on gitlab with https remote url with specific target branch in nested groups",
+			from:      "feature/commit-ui",
+			to:        "epic/ui",
+			remoteUrl: "https://gitlab.com/peter/public/calculator.git",
+			test: func(url string, err error) {
+				assert.NoError(t, err)
+				assert.Equal(t, "https://gitlab.com/peter/public/calculator/merge_requests/new?merge_request[source_branch]=feature%2Fcommit-ui&merge_request[target_branch]=epic%2Fui", url)
+			},
+		},
+		{
+			testName:  "Opens a link to new pull request on bitbucket with a custom SSH username",
+			from:      "feature/profile-page",
+			remoteUrl: "john@bitbucket.org:johndoe/social_network.git",
+			test: func(url string, err error) {
+				assert.NoError(t, err)
+				assert.Equal(t, "https://bitbucket.org/johndoe/social_network/pull-requests/new?source=feature%2Fprofile-page&t=1", url)
+			},
+		},
 		{
 			testName:  "Opens a link to new pull request on Azure DevOps (SSH)",
 			from:      "feature/new",
