@@ -2,6 +2,7 @@ package oscommands
 
 import (
 	"os"
+	"path/filepath"
 	"testing"
 
 	"github.com/stretchr/testify/assert"
@@ -135,3 +136,61 @@ func TestOSCommandFileType(t *testing.T) {
 		_ = os.RemoveAll(s.path)
 	}
 }
+
+func TestOSCommandAppendLineToFile(t *testing.T) {
+	type scenario struct {
+		path  string
+		setup func(string)
+		test  func(string)
+	}
+
+	scenarios := []scenario{
+		{
+			filepath.Join(os.TempDir(), "testFile"),
+			func(path string) {
+				if err := os.WriteFile(path, []byte("hello"), 0o600); err != nil {
+					panic(err)
+				}
+			},
+			func(output string) {
+				assert.EqualValues(t, "hello\nworld\n", output)
+			},
+		},
+		{
+			filepath.Join(os.TempDir(), "emptyTestFile"),
+			func(path string) {
+				if err := os.WriteFile(path, []byte(""), 0o600); err != nil {
+					panic(err)
+				}
+			},
+			func(output string) {
+				assert.EqualValues(t, "world\n", output)
+			},
+		},
+		{
+			filepath.Join(os.TempDir(), "testFileWithNewline"),
+			func(path string) {
+				if err := os.WriteFile(path, []byte("hello\n"), 0o600); err != nil {
+					panic(err)
+				}
+			},
+			func(output string) {
+				assert.EqualValues(t, "hello\nworld\n", output)
+			},
+		},
+	}
+
+	for _, s := range scenarios {
+		s.setup(s.path)
+		osCommand := NewDummyOSCommand()
+		if err := osCommand.AppendLineToFile(s.path, "world"); err != nil {
+			panic(err)
+		}
+		f, err := os.ReadFile(s.path)
+		if err != nil {
+			panic(err)
+		}
+		s.test(string(f))
+		_ = os.RemoveAll(s.path)
+	}
+}
