@@ -1,11 +1,12 @@
 package gui
 
 import (
+	"context"
 	"fmt"
 	"strings"
 
 	"github.com/jesseduffield/gocui"
-	"github.com/jesseduffield/lazygit/pkg/gui/context"
+	"github.com/jesseduffield/lazygit/pkg/gui/keybindings"
 	"github.com/jesseduffield/lazygit/pkg/gui/style"
 	"github.com/jesseduffield/lazygit/pkg/gui/types"
 	"github.com/jesseduffield/lazygit/pkg/theme"
@@ -16,9 +17,11 @@ import (
 // This file is for the rendering of confirmation panels along with setting and handling associated
 // keybindings.
 
-func (gui *Gui) wrappedConfirmationFunction(handlersManageFocus bool, function func() error) func() error {
+func (gui *Gui) wrappedConfirmationFunction(cancel context.CancelFunc, function func() error) func() error {
 	return func() error {
-		if err := gui.closeConfirmationPrompt(handlersManageFocus); err != nil {
+		cancel()
+
+		if err := gui.c.PopContext(); err != nil {
 			return err
 		}
 
@@ -32,9 +35,11 @@ func (gui *Gui) wrappedConfirmationFunction(handlersManageFocus bool, function f
 	}
 }
 
-func (gui *Gui) wrappedPromptConfirmationFunction(handlersManageFocus bool, function func(string) error, getResponse func() string) func() error {
+func (gui *Gui) wrappedPromptConfirmationFunction(cancel context.CancelFunc, function func(string) error, getResponse func() string) func() error {
 	return func() error {
-		if err := gui.closeConfirmationPrompt(handlersManageFocus); err != nil {
+		cancel()
+
+		if err := gui.c.PopContext(); err != nil {
 			return err
 		}
 
@@ -48,27 +53,15 @@ func (gui *Gui) wrappedPromptConfirmationFunction(handlersManageFocus bool, func
 	}
 }
 
-func (gui *Gui) closeConfirmationPrompt(handlersManageFocus bool) error {
+func (gui *Gui) deactivateConfirmationPrompt() {
 	gui.Mutexes.PopupMutex.Lock()
 	gui.State.CurrentPopupOpts = nil
 	gui.Mutexes.PopupMutex.Unlock()
 
-	// we've already closed it so we can just return
-	if !gui.Views.Confirmation.Visible {
-		return nil
-	}
-
-	if !handlersManageFocus {
-		if err := gui.c.PopContext(); err != nil {
-			return err
-		}
-	}
-
-	gui.clearConfirmationViewKeyBindings()
 	gui.Views.Confirmation.Visible = false
 	gui.Views.Suggestions.Visible = false
 
-	return nil
+	gui.clearConfirmationViewKeyBindings()
 }
 
 func (gui *Gui) getMessageHeight(wrap bool, message string, width int) int {
@@ -123,33 +116,31 @@ func (gui *Gui) getConfirmationPanelWidth() int {
 }
 
 func (gui *Gui) prepareConfirmationPanel(
-	title,
-	prompt string,
-	hasLoader bool,
-	findSuggestionsFunc func(string) []*types.Suggestion,
-	editable bool,
-	mask bool,
+	ctx context.Context,
+	opts types.ConfirmOpts,
 ) error {
-	gui.Views.Confirmation.HasLoader = hasLoader
-	if hasLoader {
-		gui.g.StartTicking()
+	gui.Views.Confirmation.HasLoader = opts.HasLoader
+	if opts.HasLoader {
+		gui.g.StartTicking(ctx)
 	}
-	gui.Views.Confirmation.Title = title
+	gui.Views.Confirmation.Title = opts.Title
 	// for now we do not support wrapping in our editor
-	gui.Views.Confirmation.Wrap = !editable
+	gui.Views.Confirmation.Wrap = !opts.Editable
 	gui.Views.Confirmation.FgColor = theme.GocuiDefaultTextColor
-	gui.Views.Confirmation.Mask = runeForMask(mask)
+	gui.Views.Confirmation.Mask = runeForMask(opts.Mask)
+	_ = gui.Views.Confirmation.SetOrigin(0, 0)
 
-	gui.findSuggestions = findSuggestionsFunc
-	if findSuggestionsFunc != nil {
+	gui.findSuggestions = opts.FindSuggestionsFunc
+	if opts.FindSuggestionsFunc != nil {
 		suggestionsView := gui.Views.Suggestions
 		suggestionsView.Wrap = false
 		suggestionsView.FgColor = theme.GocuiDefaultTextColor
-		gui.setSuggestions(findSuggestionsFunc(""))
+		gui.setSuggestions(opts.FindSuggestionsFunc(""))
 		suggestionsView.Visible = true
 		suggestionsView.Title = fmt.Sprintf(gui.c.Tr.SuggestionsTitle, gui.c.UserConfig.Keybinding.Universal.TogglePanel)
 	}
 
+	gui.resizeConfirmationPanel()
 	return nil
 }
 
@@ -160,16 +151,19 @@ func runeForMask(mask bool) rune {
 	return 0
 }
 
-func (gui *Gui) createPopupPanel(opts types.CreatePopupPanelOpts) error {
+func (gui *Gui) createPopupPanel(ctx context.Context, opts types.CreatePopupPanelOpts) error {
 	gui.Mutexes.PopupMutex.Lock()
 	defer gui.Mutexes.PopupMutex.Unlock()
 
+	ctx, cancel := context.WithCancel(ctx)
+
 	// we don't allow interruptions of non-loader popups in case we get stuck somehow
 	// e.g. a credentials popup never gets its required user input so a process hangs
 	// forever.
 	// The proper solution is to have a queue of popup options
 	if gui.State.CurrentPopupOpts != nil && !gui.State.CurrentPopupOpts.HasLoader {
 		gui.Log.Error("ignoring create popup panel because a popup panel is already open")
+		cancel()
 		return nil
 	}
 
@@ -177,14 +171,17 @@ func (gui *Gui) createPopupPanel(opts types.CreatePopupPanelOpts) error {
 	gui.clearConfirmationViewKeyBindings()
 
 	err := gui.prepareConfirmationPanel(
-		opts.Title,
-		opts.Prompt,
-		opts.HasLoader,
-		opts.FindSuggestionsFunc,
-		opts.Editable,
-		opts.Mask,
-	)
+		ctx,
+		types.ConfirmOpts{
+			Title:               opts.Title,
+			Prompt:              opts.Prompt,
+			HasLoader:           opts.HasLoader,
+			FindSuggestionsFunc: opts.FindSuggestionsFunc,
+			Editable:            opts.Editable,
+			Mask:                opts.Mask,
+		})
 	if err != nil {
+		cancel()
 		return err
 	}
 	confirmationView := gui.Views.Confirmation
@@ -195,14 +192,17 @@ func (gui *Gui) createPopupPanel(opts types.CreatePopupPanelOpts) error {
 		textArea := confirmationView.TextArea
 		textArea.Clear()
 		textArea.TypeString(opts.Prompt)
+		gui.resizeConfirmationPanel()
 		confirmationView.RenderTextArea()
 	} else {
 		if err := gui.renderString(confirmationView, style.AttrBold.Sprint(opts.Prompt)); err != nil {
+			cancel()
 			return err
 		}
 	}
 
-	if err := gui.setKeyBindings(opts); err != nil {
+	if err := gui.setKeyBindings(cancel, opts); err != nil {
+		cancel()
 		return err
 	}
 
@@ -211,7 +211,7 @@ func (gui *Gui) createPopupPanel(opts types.CreatePopupPanelOpts) error {
 	return gui.c.PushContext(gui.State.Contexts.Confirmation)
 }
 
-func (gui *Gui) setKeyBindings(opts types.CreatePopupPanelOpts) error {
+func (gui *Gui) setKeyBindings(cancel context.CancelFunc, opts types.CreatePopupPanelOpts) error {
 	actions := utils.ResolvePlaceholderString(
 		gui.c.Tr.CloseConfirm,
 		map[string]string{
@@ -223,14 +223,14 @@ func (gui *Gui) setKeyBindings(opts types.CreatePopupPanelOpts) error {
 	_ = gui.renderString(gui.Views.Options, actions)
 	var onConfirm func() error
 	if opts.HandleConfirmPrompt != nil {
-		onConfirm = gui.wrappedPromptConfirmationFunction(opts.HandlersManageFocus, opts.HandleConfirmPrompt, func() string { return gui.Views.Confirmation.TextArea.GetContent() })
+		onConfirm = gui.wrappedPromptConfirmationFunction(cancel, opts.HandleConfirmPrompt, func() string { return gui.Views.Confirmation.TextArea.GetContent() })
 	} else {
-		onConfirm = gui.wrappedConfirmationFunction(opts.HandlersManageFocus, opts.HandleConfirm)
+		onConfirm = gui.wrappedConfirmationFunction(cancel, opts.HandleConfirm)
 	}
 
 	keybindingConfig := gui.c.UserConfig.Keybinding
 	onSuggestionConfirm := gui.wrappedPromptConfirmationFunction(
-		opts.HandlersManageFocus,
+		cancel,
 		opts.HandleConfirmPrompt,
 		gui.getSelectedSuggestionValue,
 	)
@@ -238,26 +238,22 @@ func (gui *Gui) setKeyBindings(opts types.CreatePopupPanelOpts) error {
 	bindings := []*types.Binding{
 		{
 			ViewName: "confirmation",
-			Contexts: []string{string(context.CONFIRMATION_CONTEXT_KEY)},
-			Key:      gui.getKey(keybindingConfig.Universal.Confirm),
+			Key:      keybindings.GetKey(keybindingConfig.Universal.Confirm),
 			Handler:  onConfirm,
 		},
 		{
 			ViewName: "confirmation",
-			Contexts: []string{string(context.CONFIRMATION_CONTEXT_KEY)},
-			Key:      gui.getKey(keybindingConfig.Universal.ConfirmAlt1),
+			Key:      keybindings.GetKey(keybindingConfig.Universal.ConfirmAlt1),
 			Handler:  onConfirm,
 		},
 		{
 			ViewName: "confirmation",
-			Contexts: []string{string(context.CONFIRMATION_CONTEXT_KEY)},
-			Key:      gui.getKey(keybindingConfig.Universal.Return),
-			Handler:  gui.wrappedConfirmationFunction(opts.HandlersManageFocus, opts.HandleClose),
+			Key:      keybindings.GetKey(keybindingConfig.Universal.Return),
+			Handler:  gui.wrappedConfirmationFunction(cancel, opts.HandleClose),
 		},
 		{
 			ViewName: "confirmation",
-			Contexts: []string{string(context.CONFIRMATION_CONTEXT_KEY)},
-			Key:      gui.getKey(keybindingConfig.Universal.TogglePanel),
+			Key:      keybindings.GetKey(keybindingConfig.Universal.TogglePanel),
 			Handler: func() error {
 				if len(gui.State.Suggestions) > 0 {
 					return gui.replaceContext(gui.State.Contexts.Suggestions)
@@ -267,26 +263,22 @@ func (gui *Gui) setKeyBindings(opts types.CreatePopupPanelOpts) error {
 		},
 		{
 			ViewName: "suggestions",
-			Contexts: []string{string(context.SUGGESTIONS_CONTEXT_KEY)},
-			Key:      gui.getKey(keybindingConfig.Universal.Confirm),
+			Key:      keybindings.GetKey(keybindingConfig.Universal.Confirm),
 			Handler:  onSuggestionConfirm,
 		},
 		{
 			ViewName: "suggestions",
-			Contexts: []string{string(context.SUGGESTIONS_CONTEXT_KEY)},
-			Key:      gui.getKey(keybindingConfig.Universal.ConfirmAlt1),
+			Key:      keybindings.GetKey(keybindingConfig.Universal.ConfirmAlt1),
 			Handler:  onSuggestionConfirm,
 		},
 		{
 			ViewName: "suggestions",
-			Contexts: []string{string(context.SUGGESTIONS_CONTEXT_KEY)},
-			Key:      gui.getKey(keybindingConfig.Universal.Return),
-			Handler:  gui.wrappedConfirmationFunction(opts.HandlersManageFocus, opts.HandleClose),
+			Key:      keybindings.GetKey(keybindingConfig.Universal.Return),
+			Handler:  gui.wrappedConfirmationFunction(cancel, opts.HandleClose),
 		},
 		{
 			ViewName: "suggestions",
-			Contexts: []string{string(context.SUGGESTIONS_CONTEXT_KEY)},
-			Key:      gui.getKey(keybindingConfig.Universal.TogglePanel),
+			Key:      keybindings.GetKey(keybindingConfig.Universal.TogglePanel),
 			Handler:  func() error { return gui.replaceContext(gui.State.Contexts.Confirmation) },
 		},
 	}
@@ -302,18 +294,23 @@ func (gui *Gui) setKeyBindings(opts types.CreatePopupPanelOpts) error {
 
 func (gui *Gui) clearConfirmationViewKeyBindings() {
 	keybindingConfig := gui.c.UserConfig.Keybinding
-	_ = gui.g.DeleteKeybinding("confirmation", gui.getKey(keybindingConfig.Universal.Confirm), gocui.ModNone)
-	_ = gui.g.DeleteKeybinding("confirmation", gui.getKey(keybindingConfig.Universal.ConfirmAlt1), gocui.ModNone)
-	_ = gui.g.DeleteKeybinding("confirmation", gui.getKey(keybindingConfig.Universal.Return), gocui.ModNone)
-	_ = gui.g.DeleteKeybinding("suggestions", gui.getKey(keybindingConfig.Universal.Confirm), gocui.ModNone)
-	_ = gui.g.DeleteKeybinding("suggestions", gui.getKey(keybindingConfig.Universal.ConfirmAlt1), gocui.ModNone)
-	_ = gui.g.DeleteKeybinding("suggestions", gui.getKey(keybindingConfig.Universal.Return), gocui.ModNone)
+	_ = gui.g.DeleteKeybinding("confirmation", keybindings.GetKey(keybindingConfig.Universal.Confirm), gocui.ModNone)
+	_ = gui.g.DeleteKeybinding("confirmation", keybindings.GetKey(keybindingConfig.Universal.ConfirmAlt1), gocui.ModNone)
+	_ = gui.g.DeleteKeybinding("confirmation", keybindings.GetKey(keybindingConfig.Universal.Return), gocui.ModNone)
+	_ = gui.g.DeleteKeybinding("suggestions", keybindings.GetKey(keybindingConfig.Universal.Confirm), gocui.ModNone)
+	_ = gui.g.DeleteKeybinding("suggestions", keybindings.GetKey(keybindingConfig.Universal.ConfirmAlt1), gocui.ModNone)
+	_ = gui.g.DeleteKeybinding("suggestions", keybindings.GetKey(keybindingConfig.Universal.Return), gocui.ModNone)
 }
 
 func (gui *Gui) refreshSuggestions() {
 	gui.suggestionsAsyncHandler.Do(func() func() {
-		suggestions := gui.findSuggestions(gui.c.GetPromptInput())
-		return func() { gui.setSuggestions(suggestions) }
+		findSuggestionsFn := gui.findSuggestions
+		if findSuggestionsFn != nil {
+			suggestions := gui.findSuggestions(gui.c.GetPromptInput())
+			return func() { gui.setSuggestions(suggestions) }
+		} else {
+			return func() {}
+		}
 	})
 }
 
@@ -323,8 +320,8 @@ func (gui *Gui) handleAskFocused() error {
 	message := utils.ResolvePlaceholderString(
 		gui.c.Tr.CloseConfirm,
 		map[string]string{
-			"keyBindClose":   gui.getKeyDisplay(keybindingConfig.Universal.Return),
-			"keyBindConfirm": gui.getKeyDisplay(keybindingConfig.Universal.Confirm),
+			"keyBindClose":   keybindings.Label(keybindingConfig.Universal.Return),
+			"keyBindConfirm": keybindings.Label(keybindingConfig.Universal.Confirm),
 		},
 	)
 
