@@ -1,19 +1,17 @@
 package presentation
 
 import (
+	"github.com/jesseduffield/generics/slices"
 	"github.com/jesseduffield/lazygit/pkg/commands/models"
+	"github.com/jesseduffield/lazygit/pkg/gui/presentation/icons"
 	"github.com/jesseduffield/lazygit/pkg/theme"
 )
 
 func GetRemoteBranchListDisplayStrings(branches []*models.RemoteBranch, diffName string) [][]string {
-	lines := make([][]string, len(branches))
-
-	for i := range branches {
-		diffed := branches[i].FullName() == diffName
-		lines[i] = getRemoteBranchDisplayStrings(branches[i], diffed)
-	}
-
-	return lines
+	return slices.Map(branches, func(branch *models.RemoteBranch) []string {
+		diffed := branch.FullName() == diffName
+		return getRemoteBranchDisplayStrings(branch, diffed)
+	})
 }
 
 // getRemoteBranchDisplayStrings returns the display string of branch
@@ -23,5 +21,10 @@ func getRemoteBranchDisplayStrings(b *models.RemoteBranch, diffed bool) []string
 		textStyle = theme.DiffTerminalColor
 	}
 
-	return []string{textStyle.Sprint(b.Name)}
+	res := make([]string, 0, 2)
+	if icons.IsIconEnabled() {
+		res = append(res, textStyle.Sprint(icons.IconForRemoteBranch(b)))
+	}
+	res = append(res, textStyle.Sprint(b.Name))
+	return res
 }
