@@ -1,20 +1,18 @@
 package presentation
 
 import (
+	"github.com/jesseduffield/generics/slices"
 	"github.com/jesseduffield/lazygit/pkg/commands/models"
+	"github.com/jesseduffield/lazygit/pkg/gui/presentation/icons"
 	"github.com/jesseduffield/lazygit/pkg/gui/style"
 	"github.com/jesseduffield/lazygit/pkg/theme"
 )
 
 func GetRemoteListDisplayStrings(remotes []*models.Remote, diffName string) [][]string {
-	lines := make([][]string, len(remotes))
-
-	for i := range remotes {
-		diffed := remotes[i].Name == diffName
-		lines[i] = getRemoteDisplayStrings(remotes[i], diffed)
-	}
-
-	return lines
+	return slices.Map(remotes, func(remote *models.Remote) []string {
+		diffed := remote.Name == diffName
+		return getRemoteDisplayStrings(remote, diffed)
+	})
 }
 
 // getRemoteDisplayStrings returns the display string of branch
@@ -26,5 +24,10 @@ func getRemoteDisplayStrings(r *models.Remote, diffed bool) []string {
 		textStyle = theme.DiffTerminalColor
 	}
 
-	return []string{textStyle.Sprint(r.Name), style.FgBlue.Sprintf("%d branches", branchCount)}
+	res := make([]string, 0, 3)
+	if icons.IsIconEnabled() {
+		res = append(res, textStyle.Sprint(icons.IconForRemote(r)))
+	}
+	res = append(res, textStyle.Sprint(r.Name), style.FgBlue.Sprintf("%d branches", branchCount))
+	return res
 }
