@@ -5,11 +5,13 @@ package gui
 
 import (
 	"io"
+	"os"
 	"os/exec"
 	"strings"
 
 	"github.com/creack/pty"
 	"github.com/jesseduffield/gocui"
+	"github.com/jesseduffield/lazygit/pkg/utils"
 )
 
 func (gui *Gui) desiredPtySize() *pty.Winsize {
@@ -19,15 +21,16 @@ func (gui *Gui) desiredPtySize() *pty.Winsize {
 }
 
 func (gui *Gui) onResize() error {
-	if gui.State.Ptmx == nil {
-		return nil
-	}
+	gui.Mutexes.PtyMutex.Lock()
+	defer gui.Mutexes.PtyMutex.Unlock()
 
-	// TODO: handle resizing properly: we need to actually clear the main view
-	// and re-read the output from our pty. Or we could just re-run the original
-	// command from scratch
-	if err := pty.Setsize(gui.State.Ptmx, gui.desiredPtySize()); err != nil {
-		return err
+	for _, ptmx := range gui.viewPtmxMap {
+		// TODO: handle resizing properly: we need to actually clear the main view
+		// and re-read the output from our pty. Or we could just re-run the original
+		// command from scratch
+		if err := pty.Setsize(ptmx, gui.desiredPtySize()); err != nil {
+			return utils.WrapError(err)
+		}
 	}
 
 	return nil
@@ -57,20 +60,26 @@ func (gui *Gui) newPtyTask(view *gocui.View, cmd *exec.Cmd, prefix string) error
 
 	manager := gui.getManager(view)
 
+	var ptmx *os.File
 	start := func() (*exec.Cmd, io.Reader) {
-		ptmx, err := pty.StartWithSize(cmd, gui.desiredPtySize())
+		var err error
+		ptmx, err = pty.StartWithSize(cmd, gui.desiredPtySize())
 		if err != nil {
 			gui.c.Log.Error(err)
 		}
 
-		gui.State.Ptmx = ptmx
+		gui.Mutexes.PtyMutex.Lock()
+		gui.viewPtmxMap[view.Name()] = ptmx
+		gui.Mutexes.PtyMutex.Unlock()
 
 		return cmd, ptmx
 	}
 
 	onClose := func() {
-		gui.State.Ptmx.Close()
-		gui.State.Ptmx = nil
+		gui.Mutexes.PtyMutex.Lock()
+		ptmx.Close()
+		delete(gui.viewPtmxMap, view.Name())
+		gui.Mutexes.PtyMutex.Unlock()
 	}
 
 	if err := manager.NewTask(manager.NewCmdTask(start, prefix, height+oy+10, onClose), cmdStr); err != nil {
