@@ -24,19 +24,19 @@ func (gui *Gui) newCmdTask(view *gocui.View, cmd *exec.Cmd, prefix string) error
 	start := func() (*exec.Cmd, io.Reader) {
 		r, err := cmd.StdoutPipe()
 		if err != nil {
-			gui.c.Log.Warn(err)
+			gui.c.Log.Error(err)
 		}
 		cmd.Stderr = cmd.Stdout
 
 		if err := cmd.Start(); err != nil {
-			gui.c.Log.Warn(err)
+			gui.c.Log.Error(err)
 		}
 
 		return cmd, r
 	}
 
 	if err := manager.NewTask(manager.NewCmdTask(start, prefix, height+oy+10, nil), cmdStr); err != nil {
-		gui.c.Log.Warn(err)
+		gui.c.Log.Error(err)
 	}
 
 	return nil
@@ -64,6 +64,22 @@ func (gui *Gui) newStringTaskWithoutScroll(view *gocui.View, str string) error {
 	return nil
 }
 
+func (gui *Gui) newStringTaskWithScroll(view *gocui.View, str string, originX int, originY int) error {
+	manager := gui.getManager(view)
+
+	f := func(stop chan struct{}) error {
+		gui.setViewContent(view, str)
+		_ = view.SetOrigin(originX, originY)
+		return nil
+	}
+
+	if err := manager.NewTask(f, ""); err != nil {
+		return err
+	}
+
+	return nil
+}
+
 func (gui *Gui) newStringTaskWithKey(view *gocui.View, str string, key string) error {
 	manager := gui.getManager(view)
 
