@@ -14,6 +14,10 @@ const (
 	REMOTES
 	STATUS
 	SUBMODULES
+	STAGING
+	PATCH_BUILDING
+	MERGE_CONFLICTS
+	COMMIT_FILES
 	// not actually a view. Will refactor this later
 	BISECT_INFO
 )
