@@ -73,8 +73,6 @@ func chineseTranslationSet() TranslationSet {
 		MergeConflictsTitle:                 "合并冲突",
 		LcCheckout:                          "检出",
 		NoChangedFiles:                      "没有更改过文件",
-		NoFilesDisplay:                      "没有文件可显示",
-		NotAFile:                            "不是文件",
 		PullWait:                            "正在拉取…",
 		PushWait:                            "正在推送…",
 		FetchWait:                           "正在抓取…",
@@ -104,7 +102,6 @@ func chineseTranslationSet() TranslationSet {
 		LcSquashDown:                        "向下压缩",
 		LcFixupCommit:                       "修正提交（fixup）",
 		NoCommitsThisBranch:                 "该分支没有提交",
-		OnlySquashTopmostCommit:             "只能压缩最顶层的提交",
 		YouNoCommitsToSquash:                "您没有提交可以压缩",
 		Fixup:                               "修正（fixup）",
 		SureFixupThisCommit:                 "您确定要“修正”此提交吗？它将合并到下面的提交中",
