@@ -50,6 +50,8 @@ func GetTranslationSets() map[string]TranslationSet {
 		"nl": dutchTranslationSet(),
 		"en": EnglishTranslationSet(),
 		"zh": chineseTranslationSet(),
+		"ja": japaneseTranslationSet(),
+		"ko": koreanTranslationSet(),
 	}
 }
 
