@@ -63,8 +63,6 @@ func koreanTranslationSet() TranslationSet {
 		FilterUnstagedFiles:                 "Stage되지 않은 파일만 표시",
 		ResetCommitFilterState:              "필터 리셋",
 		NoChangedFiles:                      "변경된 파일이 없습니다.",
-		NoFilesDisplay:                      "표시할 파일이 없습니다",
-		NotAFile:                            "파일이 아닙니다.",
 		PullWait:                            "업데이트 중...",
 		PushWait:                            "푸시 중...",
 		FetchWait:                           "패치 중...",
@@ -94,7 +92,6 @@ func koreanTranslationSet() TranslationSet {
 		LcSquashDown:                        "squash down",
 		LcFixupCommit:                       "fixup commit",
 		NoCommitsThisBranch:                 "이 브랜치에 커밋이 없습니다.",
-		OnlySquashTopmostCommit:             "Can only squash topmost commit",
 		YouNoCommitsToSquash:                "You have no commits to squash with",
 		Fixup:                               "Fixup",
 		SureFixupThisCommit:                 "Are you sure you want to 'fixup' this commit? It will be merged into the commit below",
