@@ -21,16 +21,13 @@ var Basic = NewIntegrationTest(NewIntegrationTestArgs{
 			},
 		}
 	},
-	Run: func(
-		shell *Shell,
-		input *Input,
-		assert *Assert,
-		keys config.KeybindingConfig,
-	) {
-		assert.WorkingTreeFileCount(0)
-
-		input.PressKeys("a")
-		assert.WorkingTreeFileCount(1)
-		assert.MatchSelectedLine(Contains("myfile"))
+	Run: func(t *TestDriver, keys config.KeybindingConfig) {
+		t.Views().Files().
+			IsEmpty().
+			IsFocused().
+			Press("a").
+			Lines(
+				Contains("myfile"),
+			)
 	},
 })
