@@ -3,6 +3,7 @@ package utils
 import (
 	"sort"
 
+	"github.com/jesseduffield/generics/slices"
 	"github.com/sahilm/fuzzy"
 )
 
@@ -14,10 +15,7 @@ func FuzzySearch(needle string, haystack []string) []string {
 	matches := fuzzy.Find(needle, haystack)
 	sort.Sort(matches)
 
-	result := make([]string, len(matches))
-	for i, match := range matches {
-		result[i] = match.Str
-	}
-
-	return result
+	return slices.Map(matches, func(match fuzzy.Match) string {
+		return match.Str
+	})
 }
