@@ -25,11 +25,11 @@ git add .
 git commit -am "myfile4"
 
 cd ..
-git clone --bare ./actual actual_remote
+git clone --bare ./repo origin
 
-cd actual
+cd repo
 
 # the test is to ensure that we actually can pull these two commits back from the origin
 git reset --hard HEAD~2
-git remote add origin ../actual_remote
+git remote add origin ../origin
 git fetch origin
